/* GLOBAL */
@font-face {
    font-family: 'Lato';
    src: url('/static/common/fonts/lato-regular-webfont.woff2') format('woff2'),
         url('/static/common/fonts/lato-regular-webfont.woff') format('woff'),
         url('/static/common/fonts/lato-regular-webfont.ttf') format('truetype');
    font-weight: 400;
    font-style: normal;
}

body {
  color: #606060;
  font-family: -apple-system, "Helvetica Neue", Helvetica, Arial, sans-serif;
}

a {
  color: #333;
  text-decoration: none;
}

a:focus,
a:hover {
  color: #333;
  text-decoration: none;
  outline: none;
}

textarea {
  resize: none;
}

.nav:not(.nav-stacked, .add-item) > li > a:focus,
.nav:not(.nav-stacked, .add-item) > li > a:hover {
  text-decoration: none;
  background-color: transparent;
}

.tab-pane {
    margin-top: 15px;
}

td > .form-group {
    margin-bottom: 0;
}

.panel-footer ul.pagination {
    margin: 0;
}
.panel.panel-default .panel-footer {
    background: none;
}

.panel-heading h4 a:after {
    font-family: 'FontAwesome';
    content: "\f107";
    margin-right: 10px;
}

.panel-heading h4 a.collapsed:after {
    content:"\f105";
}

/*body {
    margin-bottom: 20px;
}*/


h1 {
    font-size: 20px;
    margin: 0;
    line-height: 50px;
}

h2 {
    font-size: 18px;
}

.sorthandle {
  padding: 0 2px;
  cursor: -webkit-grab;
}
.sorthandle:active {
  cursor: -webkit-grabbing;
}

.padded-top {
  margin-top: 15px;
}

.pull-right .btn+.btn {
  margin-left: 5px;
}

/*/////////////////////////////////*/
/*//////// MAGENCY style //////////*/

/* Magency button (my-btn) added to bootstrap button (btn) */
.my-btn {
  border-radius: 20px;
}
.my-btn:focus, .my-btn:active, .my-btn:active:focus {
  outline: none;
  box-shadow: none;
}
.my-btn:not(.btn-default) {
  color: #fff !important; /* !important to force :hover and :focus style */
  /*box-shadow: 0 2px 5px 0 rgba(0, 0, 0, 0.26);*/
}

.my-btn-default-red {
  color: #ec3535 !important; /* !important to force :hover and :focus style */
}

.my-btn-purple {
  background-color: #6e308e;
}
.my-btn-red {
  background-color: #ec3535;
}
.my-btn-red:hover, .my-btn-red:focus {
  background-color: #E31313;
}
.my-btn-blue {
  background-color: #42c2d4;
}
.my-btn-yellow {
  background-color: #f4bd48;
}
.my-btn-green {

}

.my-btn-link-red,
.my-btn-link-red:hover, .my-btn-link-red:hover {
  color: #ec3535;
}

/* Magency nav (my-nav) added to bootstrap nav (nav) */
.my-nav {
  font-size: 15px;
}
.my-nav>li.active>a,
.my-nav>li.active>a:focus,
.my-nav>li.active>a:hover {
  background-color: none;
  font-weight: bold;
}
.my-nav-red>li.active>a,
.my-nav-red>li.active>a:focus,
.my-nav-red>li.active>a:hover {
  color: #ec3535;
}

.my-nav .fa {
  display: inline-block;
  margin-right: 5px;
  font-size: 16px;
}

/*/////////////////////////////////*/

/* HEADER */
header {
  background-color: #f9f9f9;
  background-repeat: no-repeat;
  background-size: 170px;
  background-position: left -16px;
}
header .container {
  height: 50px;
  display: flex;
  justify-content: center;
  align-items: center;
  position: relative;
}

.studio-logo {
  height: 32px;
}
.user-menu-container {
  position: absolute;
  right: 15px;
  top: 6px;
}
.user-menu-container a.dropdown-toggle {
  color: #6e308e;
  padding-left: 10px;
}
.user-menu-container a.dropdown-toggle:focus,
.user-menu-container a.dropdown-toggle:hover {
  cursor: pointer;
  text-shadow: .2px 0 0 #6e308e;
}

.user-menu-container img {
  margin-left: 12px;
  width: 38px;
  height: 38px;
  box-sizing: border-box;
  border-radius: 50% 50% 50% 50%;
  box-shadow: 0 0 0 2px #fff, 0 2px 5px 2px rgba(0, 0, 0, 0.26);
}

.main-menu {
  width: 100%;
  background-color: #f9f9f9;
  border-bottom: 1px solid #eee;
  margin-bottom: 20px;
  background-repeat: no-repeat;
  background-size: 170px;
  background-position: left -66px;
}
.main-menu-index {
  padding-bottom: 10px;
}
.main-nav {
  display: flex;
  justify-content: center;
  margin-bottom: -1px;
}

.nav-item {
  width: 200px;
  border-radius: 10px 10px 0 0;
  overflow: hidden;
  margin: 0 5px;
  margin-bottom: 1px;
  border: 1px solid transparent;
  border-bottom-width: 0;
}
.nav-item:last-of-type {
  margin-right: 60px
}
.main-menu-index .nav-item {
  border-radius: 10px;
  background: #fff;
  box-shadow: 0 2px 5px 0 rgba(0, 0, 0, 0.26);
}

.nav-item-active {
  margin-bottom: 0;
  background: #fff;
  border-color: #eee;
}

.nav-item-index {
  width: initial;
  background: -webkit-radial-gradient(rgba(250,250,250,.9) 6px, rgba(250,250,250,0) 21px);
}
.main-menu-index .nav-item-index {
  visibility: hidden;
}

.nav-item:not(.nav-item-index) > a {
  padding: 4px 4px 5px 4px !important;
}
.nav-item-title {
  font-size: 24px;
  font-family: "lato";
  text-align: center;
}
.nav-item-description {
  display: none;
  font-size: 14px;
  color: #fff;
  padding: 5px 8px;
  height: 50px;
  border-radius: 2px 2px 6px 6px;
  background-image: -webkit-linear-gradient(-60deg, transparent 40%, rgba(0,0,0,.1) 100%);
}
.main-menu-index .nav-item-description {
  display: block;
}

.nav-item > a:focus,
.nav-item > a:hover {
  background-color: #fff !important;
}
.main-menu:not(.main-menu-index) .nav-item:focus,
.main-menu:not(.main-menu-index) .nav-item:hover {
  border-color: #eee;
}
.nav-item:focus .nav-item-description,
.nav-item:hover .nav-item-description {
  background-image: none;
}

.nav-item-resources a {
  color: #ec3535;
}
.nav-item-resources .nav-item-description {
  background-color: #ec3535;
}
.nav-item-sessions a {
  color: #42c2d4;
}
.nav-item-sessions .nav-item-description {
  background-color: #42c2d4;
}
.nav-item-users a {
  color: #f4bd48;
}
.nav-item-users .nav-item-description {
  background-color: #f4bd48;
}

/* HOME */
.home {
  position: absolute;
  top: 155px;
  left: 0;
  right: 0;
  bottom: 0;
  overflow-y: auto;
  padding-top: 20px;
}
.home-title {
  font-size: 24px;
  font-family: "lato";
  color: #6e308e;
  margin: 0 8px;
  line-height: 1.3em;
}
.home-discover {
  margin: 4px -24px 24px -24px;
  display: flex;
  align-items: center;
}
.home-discover .arrow {
  font-size: 36px;
  color: #ccc;
  cursor: pointer;
  padding: 0 8px;
}
.home-discover .arrow:hover {
  color: #666;
}
.home-discover-container {
  flex: 1 0 0;
  font-size: 0;
  overflow: hidden;
  padding-bottom: 16px;
  border-bottom: 1px solid #eee;
}

/* DISCOVER ITEM */
.discover-item {
  display: inline-block;
  width: calc(20% - 16px);
  margin: 8px;
  border-radius: 10px;
  overflow: hidden;
  background: #fff;
  box-shadow: 0 2px 5px 0 rgba(0, 0, 0, 0.26);
  position: relative;
}
.discover-img {
  width: 100%;
  padding-top: 56.25%;
  background-size: cover;
  background-position: center center;
  background-repeat: no-repeat;
}
.discover-tag-new {
  position: absolute;
  left: 0;
  right: 0;
  font-size: 12px;
  color: #fff;
  background: #6e308e;
  text-align: center;
  text-transform: capitalize;
  margin-top: -16px;
  display: inline-block;
  height: 16px;
  letter-spacing: .1em;
  box-shadow: 0 -2px 2px rgba(0,0,0,.25);
}
.discover-resources .discover-tag-new {
  background: #ec3535;
}
.discover-sessions .discover-tag-new {
  background: #42c2d4;
}
.discover-users .discover-tag-new {
  background: #f4bd48;
}
.discover-item p {
  font-size: 14px;
  margin: .6em .7em .7em .7em;
  line-height: 1.3em;
  height: 9.1em;
}
@media (min-width: 992px) {
  .discover-item p {
    height: 6.5em;
  }
}
.discover-item p span {
  color: #6e308e;
  font-weight: bold;
}
.discover-resources p span{
  color: #ec3535;
}
.discover-sessions p span{
  color: #42c2d4;
}
.discover-users p span{
  color: #f4bd48;
}

/* DISCOVER MODAL */
.modal-discover-item {
  overflow: hidden;
  font-size: 14px;
}
.modal-discover-item .modal-header {
  border: none;
}
.modal-discover-item .modal-body {
  padding: 0 24px 24px 24px;
}
.modal-discover-item h2 {
  color: #6e308e;
  font-size: 24px;
  margin: 1em 0 0 0;
  font-family: "lato";
}
.modal-discover-item p {
  margin-bottom: 1.5em;
}
.modal-discover-resources h2 {
  color: #ec3535;
}
.modal-discover-sessions h2 {
  color: #42c2d4;
}
.modal-discover-users h2 {
  color: #f4bd48;
}
.modal-discover-resources .my-btn {
  background: #ec3535;
}
.modal-discover-sessions .my-btn {
  background: #42c2d4;
}
.modal-discover-users .my-btn {
  background: #f4bd48;
}

/* Subtitle */
/*.page-header h2 {
  margin: 0;
}*/

/* Ajax spinner */
.spinner {
  margin: 7px;
  display: block;
  width: 16px;
  height: 16px;
  background: url(../ajax-loader.gif) no-repeat center;


}/* The surveys editor */

    /* Make inputs and textarea the same size */
    .page-cms-surveys form input[type=text], .page-cms-surveys form textarea {
        width: 90%;
    }

/* Metaplan Colors */
.metaplan_type1.panel-heading
{
    background-color: #7dd6da;
}

.metaplan_type2.panel-heading
{
    background-color: #f56dc1;
}

.metaplan_type3.panel-heading
{
    background-color: #a5de4f;
}

.metaplan_type4.panel-heading
{
    background-color: #fed201;
}

.flag {
  vertical-align: initial;
}

/* Filtering forms */
.form-inline.form-filter .form-group {
    margin-right: 10px;
}

.form-inline.form-filter fieldset {
    border: 1px solid #ddd;
    padding: 0 1.4em 1.4em 1.4em;
    margin: 0 0 1.5em 0;
}

.form-inline.form-filter legend {
    font-size: 1.2em;
    font-weight: bold;
    text-align: left;
    width: auto;
    padding: 0 10px;
    border-bottom: none;
    color: #606060
}

.date-range {
    width: 100%;
}

.date-range input.form-control {
    width: 50%;
}

/* Waiting trainings */
tbody.waiting-trainings, tbody.recent-trainings {
    border-left: solid 2px #286090;
}
tbody.waiting-trainings + thead th {
    border-top-width: 2px;
}
.waiting-trainings .spinner {
    margin: 2px 1ex 0 0;
    display: inline-block;
    position: relative;
    top: 2px;
}
.waiting-trainings td:first-of-type {
    font-style: italic;
}
.waiting-trainings th:not(:first-of-type),
.waiting-trainings td:not(:first-of-type) {
    text-align: center;
}
tbody.recent-trainings aside {
    font-style: italic;
    font-size: smaller;
    color: #286090;
}

/* Pagination using <button>

This is a copy of styles from bootstrap that only works for <a>

 */

.pagination > li > button {
  position: relative;
  float: left;
  padding: 6px 12px;
  margin-left: -1px;
  line-height: 1.42857143;
  color: #337ab7;
  text-decoration: none;
  background-color: #fff;
  border: 1px solid #ddd;
}
.pagination > li:first-child > button {
  margin-left: 0;
  border-top-left-radius: 4px;
  border-bottom-left-radius: 4px;
}
.pagination > li:last-child > button {
  border-top-right-radius: 4px;
  border-bottom-right-radius: 4px;
}
.pagination > li > button:hover,
.pagination > li > button:focus {
  z-index: 3;
  color: #23527c;
  background-color: #eee;
  border-color: #ddd;
}
.pagination > .active > button,
.pagination > .active > button:hover,
.pagination > .active > button:focus {
  z-index: 2;
  color: #fff;
  cursor: default;
  background-color: #337ab7;
  border-color: #337ab7;
}
.pagination > .disabled > button,
.pagination > .disabled > button:hover,
.pagination > .disabled > button:focus {
  color: #777;
  cursor: not-allowed;
  background-color: #fff;
  border-color: #ddd;
}
.pagination-lg > li > button {
  padding: 10px 16px;
  font-size: 18px;
  line-height: 1.3333333;
}
.pagination-lg > li:first-child > button {
  border-top-left-radius: 6px;
  border-bottom-left-radius: 6px;
}
.pagination-lg > li:last-child > button {
  border-top-right-radius: 6px;
  border-bottom-right-radius: 6px;
}
.pagination-sm > li > button {
  padding: 5px 10px;
  font-size: 12px;
  line-height: 1.5;
}
.pagination-sm > li:first-child > button {
  border-top-left-radius: 3px;
  border-bottom-left-radius: 3px;
}
.pagination-sm > li:last-child > button {
  border-top-right-radius: 3px;
  border-bottom-right-radius: 3px;
}

/* Training activities */
.activity-action {
    background: white;
    box-shadow: 0 0 1px 4px rgba(0,0,0,0.1)
}

.media-list.media-list-numbered {
    counter-reset: items;
    margin-bottom: 70px; /* For the activity-action fixed toolbar */
}
.media-list.media-list-numbered .media {
    counter-increment: items;
    padding-left: 30px;
    position: relative;
}
.media-list.media-list-numbered .media:before {
    content: counter(items);
    position: absolute;
    left: 0;
}
.media-list.media-list-numbered .answer {
    padding-left: 15px;
    position: relative;
}
.media-list.media-list-numbered .answer .correct-flag {
    width: 20px;
    display: inline-block;
}

/* Quiz question edition */
.workshop-question-answers .answer-item {
    margin-bottom: 10px;
}
.workshop-question-answers .answer-item input[type='text'] {
    width: 80%;
}
.workshop-question-answers .alert-danger {
    margin-top: 10px;
}
.workshop-question-answers .inline-choice {
    text-align: left;
}
.workshop-question-answers {
    text-align: center;
}
.workshop-question-answers #answers-empty {
    display: none;
}
.workshop-question-answers .sorthandle {
    margin-right: 10px;
}
.workshop-question-answers .inline-deletelink {
    margin-left: 10px;
}

/* Evaluation exercise edition & Questionnaire question edition */
.evaluation-exercise-criteria,
.questionnaire-question-choices {
    text-align: center;
}

.evaluation-exercise-criteria .inline-choice,
.questionnaire-question-choices .inline-choice {
    text-align: left;
    border-radius: 9px;
    padding: 5px;
    margin-bottom: 10px;
    background-color: #f5f5f5;
    border: 1px solid #ddd;
    box-shadow: 0 1px 1px rgba(0,0,0,.05)
}

.evaluation-exercise-criteria .criterion-item,
.questionnaire-question-choices .choice-item {
    position: relative;
}

.evaluation-exercise-criteria .criterion-item select {
    margin: -1px 0 4px 8px;
    height: 28px;
}
.evaluation-exercise-criteria .inline-deletelink,
.questionnaire-question-choices .inline-deletelink {
    position: absolute;
    right: 4px;
    top: 0;
}
.evaluation-exercise-criteria .criterion-item .form-group,
.questionnaire-question-choices .choice-item .form-group {
    width: 100%;
}

/* Evaluation exercise edition */
.evaluation-exercise-criteria #criteria-empty {
    display: none;
}

.form-group-start_range,
.form-group-end_range,
.form-group-step {
  display: inline-block;
  margin-right: 10px;
}
.form-group-step {
  margin-left: 40px;
}

/* Questionnaire question edition */
.questionnaire-question-choices .choice-valid {
    margin-left: 8px;
    margin-bottom: 4px;
    color: #737373;
    display: inline-block;
    cursor: pointer;
}
.questionnaire-question-choices .choice-valid.choice-success {
    color: #555;
    font-weight: 700;
}

.questionnaire-question-choices .alert-danger {
    margin-top: 10px;
}
.questionnaire-question-choices .empty-form {
    display: none;
}

/* modal activity create */
.modal-activity-create .modal-body {
  display: flex;
  flex-wrap: wrap;
  padding: 0 15px 17px 15px;
}
.activity-category {
  display: flex;
  flex-wrap: wrap;
}
.activity-category h2 {
  width: 100%;
  font-family: "Lato";
  padding-left: 8px;
  margin-bottom: 4px;
}
.activity-category_energize {
  color: #ec3535;
}
.activity-category_evaluate {
  color: #CC66B4;
  width: 50%;
}
.activity-category_support {
  color: #42c2d4;
  width: 50%;
}
.activity-item {
  width: 25%;
  padding: 8px;
}
.activity-category_evaluate .activity-item,
.activity-category_support .activity-item {
  width: 50%;
}
.activity-thumbnail {
  box-shadow: 0 2px 5px 0 rgba(0, 0, 0, 0.26);
  border-radius: 10px;
  background-color: #fff;
  text-align: center;
  padding: 4px;
  color: #333;
  position: relative;
  overflow: hidden;
}
.activity-thumbnail .activity-title {
  font-size: 14px;
  line-height: 1.2em;
  height: 2.4em;
  margin: 4px 9px;
  margin: 4px 9px 20px;
}
.activity-thumbnail .activity-icon {
  font-size: 42px;
  margin: 12px;
  display: block;
}
/*.activity-thumbnail:hover .activity-icon,
.activity-thumbnail:active .activity-icon {
  font-size: 48px;
  line-height: 42px;
}*/
.activity_energize .activity-icon {
  color: #ec3535;
}
.activity_evaluate .activity-icon {
  color: #CC66B4;
}
.activity_support .activity-icon {
  color: #42c2d4;
}
.activity-thumbnail .activity-info {
  position: absolute;
  left: 0;
  right: 0;
  bottom: 0;
  font-size: 16px;
  line-height: 22px;
  color: #e0e0e0;
  text-align: center;
}
.activity-thumbnail .activity-info:hover,
.activity-thumbnail .activity-info:active {
  color: #fff;
  font-size: 20px;
  text-shadow: 0 0.5px 3px rgba(0,0,0,.26);
}

.activity_energize:hover .activity-info,
.activity_energize:active .activity-info {
  color: #fff;
  background-color: #ec3535;
}
.activity_evaluate:hover .activity-info,
.activity_evaluate:active .activity-info {
  color: #fff;
  background-color: #CC66B4;
}
.activity_support:hover .activity-info,
.activity_support:active .activity-info {
  color: #fff;
  background-color: #42c2d4;
}

/* Training and Activities list */

.training-thumbnail {
    margin-right: 20px;
}

.back-button {
  margin-right: 10px;
}

.page-title {
  font-family: "Lato";
  font-size: 30px;
  font-weight: 400;
  line-height: 1.1em;
  margin: 6px 0 20px 0;
  color: #333;
}
.content-title {
  font-size: 18px;
  font-weight: 500;
  line-height: 1.1em;
  margin: 6px 0 20px 0;
  color: #333;
}
.small-title {
  font-size: 11px;
  font-weight: 400;
  line-height: 1;
  color: #777;
  margin: 16px 0 2px 0;
}
.separator-bottom {
  padding-bottom: 12px;
  margin-bottom: 36px;
  border-bottom: 1px solid #e5e5e5;
}

.list-filters {
    margin-bottom: 20px;
}

.list-filters .dropdown-menu {
  min-width: 560px;
  margin: -37px 0 0 -3px;
}

.list-filters .dropdown-menu .form-group {
    min-height: 50px;
}

.list-filters .dropdown-menu > div {
    padding: 10px 15px;
}

.activity-list-filters .select2-container,
.training-list-filters .select2-container {
    display: block;
}


.training-list-filters .pagination,
.activity-list-filters .pagination {
    margin: 0;
}

.scrolling-table-wrapper {
    height: calc(100vh - 300px);
    overflow-y: auto;
}

.scrolling-table-wrapper thead {
    background: white;
}

.training-row .training-actions .btn,
.activity-row .activity-actions .btn {
    visibility: hidden;
    margin: -5px 0;
}

.training-row:hover .training-actions .btn ,
.activity-row:hover .activity-actions .btn {
    visibility: visible;
}

.dropdown-menu.dropdown-training-filters,
.dropdown-menu.dropdown-activity-filters {
    min-width: 410px;
}

.dropdown-menu.dropdown-training-filters .form-group,
.dropdown-menu.dropdown-activity-filters .form-group {
    min-height: 50px;
}

.dropdown-menu.dropdown-training-filters > div,
.dropdown-menu.dropdown-activity-filters > div {
    padding: 10px 15px;
}

.training-actions .btn,
.activity-actions .btn {
    padding-top: 0;
    padding-bottom: 0;
}

.scrolling-training-wrapper {
  height: calc(100vh - 225px);
  overflow-y: auto;
}

.trainings-table td,
.activities-table td {
  color: rgba(0,0,0,.5);
}
.trainings-table thead button {
  margin: -3px 0;
}
.training-status-icon {
  color: #606060;
}
.activity-type-icon {
  color: #606060;
  font-size: 1.72em;
  width: 1em;
  display: inline-block;
  position: relative;
}
.activity-type-icon::before {
  position: absolute;
  margin-top: -.7em;
}
.trainings-table td strong,
.activities-table td strong {
  font-weight: normal;
  color: #333;
}


.add-item>li {
  float: right;
}


/* Presentation */
.presentation-thumbnail .thumbnail {
    width: 200px;
    height: 100px;
}

.presentation-thumbnail .thumbnail .img-wrapper {
    width: 190px;
    height: 90px;
    overflow: hidden;
}

.presentation-thumbnail .thumbnail .img-wrapper img {
    max-width: 190px;
}

.presentation-thumbnail .thumbnail.thumbnail-loading {
    padding-top: 20px;
    color: #8c8c8c;
}

/* Quiz */
.questions-list .question-img {
    padding: 0;
    width: 66px; /*16/9 ratio*/
    height: 37px;
    background-size: cover;
    background-repeat: no-repeat;
    background-position: center;
}
.question-types {
  display: flex;
  flex-wrap: wrap;
  justify-content: center;
}
.question-type-thumbnail {
  min-height: 134px;
  line-height: 1.2em;
}
.question-types .activity-item:nth-of-type(1) .fa {
  color: #ec3535 !important; /*to force :hover and :active color*/
}
.question-types .activity-item:nth-of-type(2) .fa {
  color: #6e308e !important; /*to force :hover and :active color*/
}
.question-types .activity-item:nth-of-type(3) .fa {
  color: #BD5DA1 !important; /*to force :hover and :active color*/
}

/* Progress bar container */
#progressWrapper {
    width: 100%;
    height: 100%;
    position: absolute;
    padding: 50% 40% 0 40%;
    top: 0;
    left: 0;
    background-color: rgba(255, 255, 255, 0.7);
}
#progressContainer {
    width: 100%;
    height: 100%;
    top: 0;
    left: 0;
}
