<div class="modal-content">
    <div class="modal-header">
        <button type="button" class="close" data-dismiss="modal" aria-label="Close"><span aria-hidden="true">&times;</span></button>
        <h4></h4>
    </div>
    <div class="discover-img" style="background-image: url('{{ discoveritem.image.url }}');" alt="{{ discoveritem.title }}"></div>
    <div class="text-center modal-body modal-discover-{{ discoveritem.category }}">
        <h2 class="text-left">{{ discoveritem.title }}</h2>
        <p class="text-left">
            {{ discoveritem.long_description }}
        </p>
        {% if discoveritem.link_url and discoveritem.link_title %}
            <a class="btn my-btn my-btn-purple" href="{{ discoveritem.link_url }}">{{ discoveritem.link_title }}</a>
        {% elif discover_link_url and discoveritem.link_title %}
            <a class="btn my-btn my-btn-purple" href="{{ discover_link_url }}">{{ discoveritem.link_title }}</a>
        {% endif %}
    </div>
</div>
