"""This module contains the urls of the ``cms`` app"""

from macrosurl import url

from . import views


app_name = 'cms'

urlpatterns = [
    # Cms index
    url(r'^$', views.Index.as_view(), name='index'),
    # Discover item detail
    url(
        r'discover/:slug/',
        views.DiscoverItemDetailView.as_view(),
        name='discover_detail'
    ),
]
