{% extends "layout/2-columns-left.html" %}
{% load i18n staticfiles template_tools compress %}

{% block head %}
    {{ block.super }}
    {% compress js %}
        <script type="text/javascript" src="{{ STATIC_URL }}common/js/ajax-modal.js"></script>
        <script type="text/javascript" src="{{ STATIC_URL }}common/js/url-modal.js"></script>
        <script type="text/javascript" src="{{ STATIC_URL }}common/js/sticky-table-header.js"></script>
        <script type="text/javascript" src="{{ STATIC_URL }}common/js/ajaxForm.jquery.min.js"></script>
        <script type="text/javascript" src="{{ STATIC_URL }}common/js/autoAjaxForm.js"></script>
    {% endcompress %}
{% endblock %}

{% block page-header %}{% endblock %}
{% block subtitle %}{% endblock %}
{% block actions %}{% endblock %}

{% block column_left %}
    <ul class="nav nav-stacked my-nav my-nav-red">
        <li role="presentation" class="{% if current_sub_section == 'training' %}active{% endif %}">
            <a href="{% url 'trainings:training-list' %}">
                <i class="fa fa-list-ul"></i>
                {% trans 'My scenarios' %}
            </a>
        </li>
        <li role="presentation" class="{% if current_sub_section == 'private_library' %}active{% endif %}">
            <a href="{% url 'trainings:activities-private-library' %}">
                <i class="fa fa-star"></i>
                {% trans 'My activities' %}
            </a>
        </li>
        <li role="presentation" class="{% if current_sub_section == 'public_library' %}active{% endif %}">
            <a href="{% url 'trainings:activities-public-library' %}">
                <i class="fa fa-share-alt"></i>
                {% trans 'Shared activities' %}
            </a>
        </li>
    </ul>
{% endblock %}
