# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
from django.conf import settings


class Migration(migrations.Migration):

    dependencies = [
        ('tasks', '0004_djangotask_state'),
    ]

    operations = [
        migrations.AlterField(
            model_name='djangotask',
            name='user',
            field=models.ForeignKey(related_name='tasks', verbose_name='User', to=settings.AUTH_USER_MODEL, null=True),
        ),
    ]
