{% extends 'base.html' %}
{% load i18n %}

{% block subtitle %}
	{% if competency.pk %}
		{% trans 'Edit' %} "{{ competency.name }}"
	{% else %}
		{% blocktrans trimmed with job_profile_name=current_job_profile.name %}
			New competency for "{{ job_profile_name }}"
		{% endblocktrans %}
	{% endif %}
{% endblock %}

{% block actions %}
	<a href="{{ competency_tree.get_competency_list_url }}" class="btn btn-default">
		{% trans 'Back to the competency list' %}
	</a>
{% endblock %}

{% block main %}
	<form action="{% if competency.pk %}{{ competency.get_edit_url }}{% else %}{% url 'assessments:competency-create' jobprofile_uuid=current_job_profile.id %}{% endif %}" method="post">{% csrf_token %}
		{% include 'extras/form.html' %}
		<hr>
		<div class="clearfix">
			<a href="{{ competency_tree.get_competency_list_url }}" class="btn btn-default pull-left">
				{% trans 'Cancel' %}
			</a>
			<input class="btn btn-primary pull-right" type="submit" value="{% trans 'Confirm' %}" />
		</div>
	</form>
{% endblock %}
