# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('assessments', '0021_userlessonrecommendation_score'),
    ]

    operations = [
        migrations.AddField(
            model_name='recommendationlevel',
            name='is_reference',
            field=models.BooleanField(default=False),
        ),
    ]
