# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('assessments', '0020_certificationstatus_is_reference'),
    ]

    operations = [
        migrations.AddField(
            model_name='userlessonrecommendation',
            name='score',
            field=models.PositiveIntegerField(default=0),
            preserve_default=False,
        ),
    ]
