"""This module contains the forms for the ``photostories`` app"""

from mtp.apps.trainings.forms import TrainingActivityForm

from .models import Photostory


class PhotostoryForm(TrainingActivityForm):
    """Form for the ``Photostory`` model"""

    class Meta:
        fields = TrainingActivityForm.Meta.fields
        model = Photostory
