{% load i18n %}

<div class="modal fade" id="activity-create">
    <div class="modal-dialog modal-activity-create" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <button type="button" class="close" data-dismiss="modal" aria-label="Close"><span aria-hidden="true">&times;</span></button>
                <h4 class="modal-title">{% trans 'New content' %}</h4>
            </div>
            <div class="modal-body clearfix">
                <div class="activity-category activity-category_energize">
                    <h2>{{ ACTIVITY_CATEGORIES.ENERGIZE.display }}</h2>
                    {% for activity_type in available_activity_types.energize %}
                        <div class="activity-item">
                            <a href="{{ activity_type.create_url }}" class="dialog-box activity_energize" data-dismiss="modal">
                                <div class="activity-thumbnail">
                                    <i class="activity-icon icon-{{ activity_type.type }}"></i>
                                    <p class="activity-title">{{ activity_type.verbose_name }}</p>
                                    <i class="dialog-box fa fa-info-circle activity-info" data-modal-classes="modal-discover-item" data-href="{% url 'cms:discover_detail' slug=activity_type.type %}" data-dismiss="modal"></i>
                                </div>
                            </a>
                        </div>
                    {% endfor %}
                </div>
                <div class="activity-category activity-category_evaluate">
                    <h2>{{ ACTIVITY_CATEGORIES.EVALUATE.display }}</h2>
                    {% for activity_type in available_activity_types.evaluate %}
                        <div class="activity-item">
                            <a href="{{ activity_type.create_url }}" class="dialog-box activity_evaluate" data-dismiss="modal">
                                <div class="activity-thumbnail">
                                    <i class="activity-icon icon-{{ activity_type.type }}"></i>
                                    <p class="activity-title">{{ activity_type.verbose_name }}</p>
                                    <i class="dialog-box fa fa-info-circle activity-info" data-modal-classes="modal-discover-item" data-href="{% url 'cms:discover_detail' slug=activity_type.type %}" data-dismiss="modal"></i>
                                </div>
                            </a>
                        </div>
                    {% endfor %}
                </div>
                <div class="activity-category activity-category_support">
                    <h2>{{ ACTIVITY_CATEGORIES.SUPPORT.display }}</h2>
                    {% for activity_type in available_activity_types.support %}
                        <div class="activity-item">
                            <a href="{{ activity_type.create_url }}" class="dialog-box activity_support" data-dismiss="modal">
                                <div class="activity-thumbnail">
                                    <i class="activity-icon icon-{{ activity_type.type }}"></i>
                                    <p class="activity-title">{{ activity_type.verbose_name }}</p>
                                    <i class="dialog-box fa fa-info-circle activity-info" data-modal-classes="modal-discover-item" data-href="{% url 'cms:discover_detail' slug=activity_type.type %}" data-dismiss="modal"></i>
                                </div>
                            </a>
                        </div>
                    {% endfor %}
                </div>
            </div>
        </div>
    </div>
</div>
