{% comment %}
    Override django/forms/templates/django/forms/widgets/multiwidget.html
    only to add a separator between both date inputs
    ie the only thing added is the {% if %} block
{% endcomment %}
{% for widget in widget.subwidgets %}
    {% include widget.template_name %}
{% endfor %}
