# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('translation', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='translatablelanguage',
            name='first_update',
            field=models.ForeignKey(related_name='translation_translatablelanguage_by_first', null=True, to='sync.Update', blank=True),
        ),
        migrations.AlterField(
            model_name='translatablelanguage',
            name='last_update',
            field=models.ForeignKey(related_name='translation_translatablelanguage_by_last', null=True, to='sync.Update', blank=True),
        ),
        migrations.AlterField(
            model_name='translation',
            name='first_update',
            field=models.ForeignKey(related_name='translation_translation_by_first', null=True, to='sync.Update', blank=True),
        ),
        migrations.AlterField(
            model_name='translation',
            name='last_update',
            field=models.ForeignKey(related_name='translation_translation_by_last', null=True, to='sync.Update', blank=True),
        ),
    ]
