{% extends 'modal_base.html' %}
{% load i18n %}

{% block title %}
    {% trans 'Deletion confirmation' %}
{% endblock %}

{% block body %}
<form action="{{ lessondimensionweight.get_delete_url }}" method="post">{% csrf_token %}
    <div class="modal-body">
        <p>
            {% blocktrans trimmed with job_profile_name=current_job_profile.name competency_name=object.name %}
                Are you sure you want to delete this dimension weight?
            {% endblocktrans %}
        </p>
    </div>
    <div class="modal-footer clearfix">
        <button type="button" class="btn btn-default pull-left" data-dismiss="modal">{% trans 'Cancel' %}</button>
        <input class="btn btn-danger pull-right" type="submit" value="{% trans 'Confirm' %}" />
    </div>
</form>
{% endblock %}
